/* Copyright ? 2005, Stylegraph, Inc.  All rights reserved. */
var updateDateTimer = null;
var infoVisible = false;
var fade = { duration: 500, startTime: 0, to: 1.0, now: 0.0, from: 0.0, timer: null, frameRate: 13 };

function loadWidget() {
	if (widget) {
		widget.onhide = onhide;
		widget.onshow = onshow;
		widget.onremove = removeWidget;

		if (!widget.preferenceForKey(widget.identifier + "-EventName")) widget.setPreferenceForKey(getLocalizedString("Next New Year's Day"), widget.identifier + "-EventName");
		if (!widget.preferenceForKey(widget.identifier + "-EventDate")) {
			var nowDate = new Date();
			var nextYear = nowDate.getFullYear() + 1;
			widget.setPreferenceForKey("1/1/" + nextYear, widget.identifier + "-EventDate");
		}
		if (!widget.preferenceForKey(widget.identifier + "-PanelColor")) widget.setPreferenceForKey("Blue", widget.identifier + "-PanelColor");
	}
	var infoButton = new AppleInfoButton(document.getElementById('Info'), document.getElementById('Front'), 'white', 'white', clickInfo);
	var doneButton = new AppleGlassButton (document.getElementById('Done'), '完了', clickDone);
	setFrontValue();
}

function removeWidget() {
	if (widget) {
		widget.setPreferenceForKey(null, widget.identifier + "-EventName");
		widget.setPreferenceForKey(null, widget.identifier + "-EventDate");
		widget.setPreferenceForKey(null, widget.identifier + "-PanelColor");
	}
}

function setFrontValue() {
	if (widget) {
		var eventName = widget.preferenceForKey(widget.identifier + "-EventName");
		var eventDate = widget.preferenceForKey(widget.identifier + "-EventDate");
		var panelColor = widget.preferenceForKey(widget.identifier + "-PanelColor");
	}
	var eventDateMillisec = Date.parse(eventDate);
	var nowDate = new Date();
	var nowYear = nowDate.getFullYear();
	var nowMonth = nowDate.getMonth() + 1;
	var nowDay = nowDate.getDate();
	var nowDateMillisec = Date.parse(nowMonth + "/" + nowDay + "/" + nowYear);
	var dayCount = Math.ceil((eventDateMillisec - nowDateMillisec) / 86400000);

	document.getElementById("Front").className = panelColor;
	document.getElementById("EventName").innerHTML = eventName;
	if (dayCount > 0) {
		document.getElementById("Preposition").innerHTML = getLocalizedString("Until");
	} else {
		dayCount = dayCount * -1;
		document.getElementById("Preposition").innerHTML = getLocalizedString("Since");
	}
	if (dayCount > 1) document.getElementById("Day").innerHTML = getLocalizedString("Days");
	else document.getElementById("Day").innerHTML = getLocalizedString("Day");

	dayCount += "";
	setStringStyle(dayCount);
	document.getElementById("Count").innerHTML = dayCount;

	var hoursMillisec = (23 - nowDate.getHours()) * 3600000;
	var minutesMillisec = (59 - nowDate.getMinutes()) * 60000;
	var secondsMillisec = (60 - nowDate.getSeconds()) * 1000;
	var updateDateMillisec = hoursMillisec + minutesMillisec + secondsMillisec;
	updateDateTimer = setTimeout("setFrontValue()", updateDateMillisec);
}

function setBackValue() {
	document.getElementById("LabelEventName").innerHTML = getLocalizedString("Event Name") + " :";
	document.getElementById("LabelEventDate").innerHTML = getLocalizedString("Event Date") + " :";
	document.getElementById("LabelPanelColor").innerHTML = getLocalizedString("Color") + " :";
	if (widget) {
		document.getElementById("InputEventName").value = widget.preferenceForKey(widget.identifier + "-EventName");
		writeCalender(widget.preferenceForKey(widget.identifier + "-EventDate"));
		writeColorTable(widget.preferenceForKey(widget.identifier + "-PanelColor"));
	}
}

function setEventName(eventName) {
	if (widget) widget.setPreferenceForKey(eventName, widget.identifier + "-EventName");
}

function setEventDay(eventDate) {
	if (widget) widget.setPreferenceForKey(eventDate, widget.identifier + "-EventDate");
	writeCalender(eventDate);
}

function setPanelColor(panelColor) {
	if (widget) widget.setPreferenceForKey(panelColor, widget.identifier + "-PanelColor");
	writeColorTable(panelColor);
}

function writeCalender(calenderDate) {
	var calenderTable;
	var weekStrings = new Array(getLocalizedString("Sun"), getLocalizedString("Mon"), getLocalizedString("Tue"), getLocalizedString("Wed"), getLocalizedString("Thu"), getLocalizedString("Fri"), getLocalizedString("Sat"));
	var daysOfMonth = new Array(0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
	var aryCalenderDate = calenderDate.split("/");
	var calenderYear = parseInt(aryCalenderDate[2]);
	var calenderMonth = parseInt(aryCalenderDate[0]);
	var calenderWeek = new Date(calenderYear, calenderMonth - 1, 1).getDay();
	var previousYear = calenderYear;
	var previousMonth = calenderMonth - 1;
	var nextYear = calenderYear;
	var nextMonth = calenderMonth + 1;

	var aryEventDate = widget.preferenceForKey(widget.identifier + "-EventDate").split("/");
	var eventYear = parseInt(aryEventDate[2]);
	var eventMonth = parseInt(aryEventDate[0]);
	var eventDay = parseInt(aryEventDate[1]);

	if ((calenderYear % 4 == 0 && calenderYear % 100 != 0) || calenderYear % 400 == 0) daysOfMonth[2] = 29;
	switch (calenderMonth) {
	case 1:
		previousYear = calenderYear - 1;
		previousMonth = 12;
		break;
	case 12:
		nextYear = calenderYear + 1;
		nextMonth = 1;
		break;
	}
	calenderTable = "<table><tr>";
	calenderTable += "<td><img src=\"Images/ButtonLeft.png\" width=\"13\" height=\"13\" onclick=\"writeCalender('" + previousMonth + "/1/" + previousYear + "')\"></td>";
	calenderTable += "<td colspan=\"5\">" + calenderYear + " / " + calenderMonth + "</td>";
	calenderTable += "<td><img src=\"Images/ButtonRight.png\" width=\"13\" height=\"13\" onclick=\"writeCalender('" + nextMonth + "/1/" + nextYear + "')\"></td></tr><tr>";
	for ( i = 0; i < 7; i++) calenderTable += "<td>" + weekStrings[i] + "</td>";
	calenderTable += "</tr>";
	for (i = 0; i < daysOfMonth[calenderMonth] + calenderWeek; i++) {
		calenderDay = i - calenderWeek + 1;
		if (i % 7 == 0) calenderTable += "<tr>";
		if (calenderDay < 1) calenderTable += "<td>&nbsp;</td>";
		else if (calenderDay == eventDay && calenderMonth == eventMonth && calenderYear == eventYear) calenderTable += "<td class=\"CalenderEventDay\">" + calenderDay + "</td>";
		else calenderTable += "<td class=\"CalenderDay\" onclick=\"setEventDay('" + calenderMonth + "/" + calenderDay +  "/" + calenderYear + "')\">" + calenderDay + "</td>";
		if (i % 7 == 6) calenderTable += "</tr>";
	}
	while (i % 7 != 6) {
		i ++;
		calenderTable += "<td>&nbsp;</td>";
		if (i % 7 == 6) calenderTable += "</tr>";
	}
	calenderTable += "</table>";
	document.getElementById("Calender").innerHTML = calenderTable;
}

function writeColorTable(panelColor) {
	var colorTable;
	var color = new Array("Blue", "Green", "Orange", "Red", "Purple");

	colorTable = "<table><tr>"
	for (i = 0; i < color.length; i++) {
		colorTable += "<td class=\"" + color[i] + "\" onclick=\"setPanelColor('" + color[i] + "')\">";
		if (color[i] == panelColor) colorTable += "<img src=\"Images/Check.png\" />";
		else colorTable += "&nbsp;";
		colorTable += "</td>";
	}
	colorTable += "</tr></table>";
	document.getElementById("ColorTable").innerHTML = colorTable;
}

function clickInfo() {
	setBackValue();
	if (widget) {
		resizeTo(160, 300);
		widget.prepareForTransition("ToBack");
	}
	document.getElementById("Front").style.display = "none";
	document.getElementById("Back").style.display = "block";
	if (widget) setTimeout("widget.performTransition()", 0);
}

function clickDone() {
	setFrontValue();
	if (widget) widget.prepareForTransition("ToFront");
	document.getElementById("Front").style.display = "block";
	document.getElementById("Back").style.display = "none";
	if (widget) {
		resizeTo(160, 120);
		setTimeout("widget.performTransition()", 0);
	}
}

function openUrl(strUrl) {
	if (widget) widget.openURL(strUrl);
}

function onshow() {
	setFrontValue();
}

function onhide() {
	if (updateDateTimer) {
		clearTimeout(updateDateTimer);
		updateDateTimer = null;
	}
}

function getLocalizedString (key)
{
	try {
		var ret = localizedStrings[key];
		if (ret === undefined)
			ret = key;
		return ret;
	} catch (ex) {}

	return key;
}
